@@ -301,6 +301,8 @@ void KameraProtocol::stat(const KURL &url)
 
 		kdDebug(7123) << "redirecting to /" << endl;
 		rooturl.setPath("/");
+		rooturl.setHost(url.host());
+		rooturl.setUser(url.user());
 		redirection(rooturl);
 		finished();
 		return;
@@ -342,6 +344,7 @@ void KameraProtocol::statRegular(const KURL &url)
 	UDSEntry entry;
 	int gpr;
 
+	kdDebug(7123) << "statRegular(\"" << url.path() << "\")" << endl;
 	if (openCamera() == false) {
 		error(KIO::ERR_DOES_NOT_EXIST, url.path());
 		return;
@@ -582,6 +585,18 @@ void KameraProtocol::listDir(const KURL &url)
 		return;
 	}
 
+	if (url.path() == "") {
+		KURL rooturl(url);
+
+		kdDebug(7123) << "redirecting to /" << endl;
+		rooturl.setPath("/");
+		rooturl.setHost(url.host());
+		rooturl.setUser(url.user());
+		redirection(rooturl);
+		finished();
+		return;
+	}
+
 	if (!openCamera()) {
 		error(KIO::ERR_COULD_NOT_READ,url.path());
 		return;
@@ -850,6 +865,10 @@ void KameraProtocol::translateDirectoryToUDS(UDSEntry &udsEntry, const QString &
 	atom.m_long = S_IRUSR | S_IRGRP | S_IROTH |
 			S_IWUSR | S_IWGRP | S_IWOTH;
 	udsEntry.append(atom);
+
+        atom.m_uds = UDS_MIME_TYPE;
+        atom.m_str = "inode/directory";
+        udsEntry.append(atom);
 }
 
 bool KameraProtocol::cameraSupportsDel(void)
@@ -946,7 +965,7 @@ unsigned int frontendProgressStart(
 #endif
 
 	object->infoMessage(QString::fromLocal8Bit(status));
-	delete status;
+	delete [] status;
 	object->totalSize((int)totalsize); // hack: call slot directly
 	return GP_OK;
 }
@@ -986,5 +1005,5 @@ static void frontendCameraStatus(GPContext * /*context*/, const char *format, va
 	vsnprintf(status, 300, format, args);
 #endif
 	object->infoMessage(QString::fromLocal8Bit(status));
-	delete status;
+	delete [] status;
 }
