@@ -1,13 +1,14 @@
-#ifndef __KDVIMULTIPAGE_H
-#define __KDVIMULTIPAGE_H
+// -*- C++ -*-
+#ifndef KDVIMULTIPAGE_H
+#define KDVIMULTIPAGE_H
+
+#include "kmultipage.h"
+#include "dviRenderer.h"
 
 #include <qstringlist.h>
 
 class KPrinter;
 
-#include "../kviewshell/kmultipage.h"
-#include "dviwin.h"
-
 class KDVIMultiPage : public KMultiPage
 {
   Q_OBJECT
@@ -20,28 +21,25 @@ public:
 // Interface definition start ------------------------------------------------
 
   /// returns the list of supported file formats
-  virtual QStringList fileFormats();
+  virtual QStringList fileFormats() const;
   
-  /// opens a file
-  virtual bool openFile();
-  
-  virtual bool print(const QStringList &pages, int current);
+  virtual void setFile(bool r);
+
+  virtual void print();
   
   /// KDVI offers read- and write functionality must re-implement this
   /// method and return true here.
-  virtual bool isReadWrite() {return true;};
-
-  /// multipage implementations that offer read- and write
-  /// functionality should re-implement this method.
-  virtual bool isModified();
+  virtual bool isReadWrite() {return true;}
 
   virtual void addConfigDialogs(KConfigDialog* configDialog);
 
   static KAboutData* createAboutData();
 
 private:
-  virtual documentWidget* createDocumentWidget();
-  
+  virtual DocumentWidget* createDocumentWidget();
+
+  virtual void initializePageCache();
+
   /** Used to enable the export menu when a file is successfully
       loaded. */
   virtual void enableActions(bool);
@@ -54,33 +52,33 @@ public slots:
   /** Similar to slotSave, but does not ask for a filename. */
   virtual void slotSave_defaultFilename();
 
-  void setEmbedPostScriptAction(void);
+  void setEmbedPostScriptAction();
 
-  void slotEmbedPostScript(void);
+  void slotEmbedPostScript();
 
-protected:
-  /// For internal use only. See the comments in kdvi_multipage.cpp, right
-  //before the timerEvent function.
-  int  timer_id;
-  /// For internal use only. See the comments in kdvi_multipage.cpp, right
-  //before the timerEvent function.
-  void timerEvent( QTimerEvent *e );
+  virtual void preferencesChanged();
 
-  virtual void reload();
+  /** Shows the "text search" dialog, if text search is supported by
+      the renderer. Otherwise, the method returns immediately.
+      We reimplement this slot to show a warning message that informs the
+      user about the currently limited search capabilities of KDVI. */
+  virtual void showFindTextDialog();
 
 protected slots:
   void doExportText();
   void doEnableWarnings();
-  void preferencesChanged();
 
-  void showTip(void);
-  void showTipOnStart(void);
+  void showTip();
+  void showTipOnStart();
 
 private:
   // Points to the same object as renderer to avoid downcasting.
   // FIXME: Remove when the API of the Renderer-class is finished.
   dviRenderer     DVIRenderer;
-  KPrinter        *printer;
+
+  // Set to true if we used the search function atleast once.
+  // It is used to remember if we already have show the warning message.
+  bool searchUsed;
 
   /*************************************************************
    * Methods and classes concerned with the find functionality *
@@ -91,7 +89,6 @@ private:
   KAction      *docInfoAction;
   KAction      *embedPSAction;
   KAction      *exportPDFAction;
-  KAction      *exportTextAction;
   KAction      *exportPSAction;
 };
 
