@@ -123,10 +123,10 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 	KButtonBox *bbox = new KButtonBox( this );
 	bbox->addStretch( 10 );
 
-	apply = bbox->addButton( i18n("&Apply") );
+	apply = bbox->addButton( KStdGuiItem::apply() );
 	connect( apply, SIGNAL(clicked()), SLOT(slotApplyClicked()) );
 
-	QPushButton *closebtn = bbox->addButton( i18n("&Close") );
+	QPushButton *closebtn = bbox->addButton( KStdGuiItem::close() );
 	connect( closebtn, SIGNAL(clicked()), SLOT(reject()) );
 
 
