@@ -12,11 +12,13 @@
 #include <qdir.h>
 #include <qfile.h>
 #include <qfileinfo.h>
+#include <qimage.h>
 #include <qtextstream.h>
 #include <qvaluevector.h>
 #include <qtimer.h>
 #include <qmap.h>
 #include <kdebug.h>
+#include <kimageio.h>
 #include <klocale.h>
 #include <kfinddialog.h>
 #include <kmessagebox.h>
@@ -31,6 +33,7 @@
 #include "page.h"
 #include "link.h"
 #include "generator_pdf/generator_pdf.h"  // PDF generator
+#include "generator_kimgio/generator_kimgio.h"  // KIMGIO generator
 #include "conf/settings.h"
 
 // structures used internally by KPDFDocument for local variables storage
@@ -50,6 +53,9 @@ class KPDFDocumentPrivate
         QString docFileName;
         QString xmlFileName;
 
+        // a list of the mimetypes qimage can understand
+        QStringList kimgioMimes;
+
         // viewport stuff
         QValueList< DocumentViewport > viewportHistory;
         QValueList< DocumentViewport >::iterator viewportIterator;
@@ -105,6 +111,14 @@ KPDFDocument::KPDFDocument()
     d->allocatedPixmapsTotalMemory = 0;
     d->memCheckTimer = 0;
     d->saveBookmarksTimer = 0;
+    KImageIO::registerFormats();
+    QStringList list = QImage::inputFormatList();
+    QStringList::Iterator it = list.begin();
+    while( it != list.end() )
+    {
+        d->kimgioMimes << KMimeType::findByPath(QString("foo.%1").arg(*it), 0, true)->name();
+        ++it;
+    }
 }
 
 KPDFDocument::~KPDFDocument()
@@ -135,15 +149,28 @@ bool KPDFDocument::openDocument( const QString & docFile, const KURL & url, cons
     d->xmlFileName = locateLocal( "data", fn );
 
     // create the generator based on the file's mimetype
-    QString mimeName = mime->name();
-    if ( mimeName == "application/pdf" )
+    if ( (*mime).is( "application/pdf" ) )
         generator = new PDFGenerator( this );
 //    else if ( mimeName == "application/postscript" )
 //        kdError() << "PS generator not available" << endl;
     else
     {
-        kdWarning() << "Unknown mimetype '" << mimeName << "'." << endl;
-        return false;
+        QStringList::Iterator it = d->kimgioMimes.begin();
+        while( it != d->kimgioMimes.end() )
+        {
+            kdDebug() << *it << endl;
+            if ( (*mime).is( *it ) )
+            {
+                generator = new KIMGIOGenerator( this );
+                break;
+            }
+            ++it;
+        }
+        if ( it == d->kimgioMimes.end() )
+        {
+            kdWarning() << "Unknown mimetype '" << mime->name() << "'." << endl;
+            return false;
+        }
     }
 
     // 1. load Document (and set busy cursor while loading)
@@ -212,6 +239,8 @@ void KPDFDocument::closeDocument()
     delete generator;
     generator = 0;
 
+    d->url = KURL();
+
     // remove requests left in queue
     QValueList< PixmapRequest * >::iterator sIt = d->pixmapRequestsStack.begin();
     QValueList< PixmapRequest * >::iterator sEnd = d->pixmapRequestsStack.end();
@@ -359,6 +388,11 @@ uint KPDFDocument::pages() const
     return pages_vector.size();
 }
 
+KURL KPDFDocument::currentDocument() const
+{
+    return d->url;
+}
+
 bool KPDFDocument::isAllowed( int flags ) const
 {
     return generator ? generator->isAllowed( flags ) : false;
@@ -379,6 +413,21 @@ QString KPDFDocument::getMetaData( const QString & key, const QString & option )
     return generator ? generator->getMetaData( key, option ) : QString();
 }
 
+bool KPDFDocument::supportsSearching() const
+{
+    return generator ? generator->supportsSearching() : false;
+}
+
+bool KPDFDocument::hasFonts() const
+{
+    return generator ? generator->hasFonts() : false;
+}
+
+void KPDFDocument::putFontInfo(KListView *list)
+{
+    if (generator) generator->putFontInfo(list);
+}
+
 void KPDFDocument::requestPixmaps( const QValueList< PixmapRequest * > & requests )
 {
     if ( !generator )
@@ -681,7 +730,7 @@ bool KPDFDocument::searchText( int searchID, const QString & text, bool fromStar
             {
                 if ( currentPage >= pageCount )
                 {
-                    if ( noDialogs || KMessageBox::questionYesNo(0, i18n("End of document reached.\nContinue from the beginning?")) == KMessageBox::Yes )
+                    if ( noDialogs || KMessageBox::questionYesNo(0, i18n("End of document reached.\nContinue from the beginning?"), QString::null, KStdGuiItem::cont(), KStdGuiItem::cancel()) == KMessageBox::Yes )
                         currentPage = 0;
                     else
                         break;
@@ -720,9 +769,9 @@ bool KPDFDocument::searchText( int searchID, const QString & text, bool fromStar
             if ( moveViewport )
             {
                 DocumentViewport searchViewport( currentPage );
-                searchViewport.reCenter.enabled = true;
-                searchViewport.reCenter.normalizedCenterX = (match->left + match->right) / 2.0;
-                searchViewport.reCenter.normalizedCenterY = (match->top + match->bottom) / 2.0;
+                searchViewport.rePos.enabled = true;
+                searchViewport.rePos.normalizedX = (match->left + match->right) / 2.0;
+                searchViewport.rePos.normalizedY = (match->top + match->bottom) / 2.0;
                 setViewport( searchViewport, -1, true );
             }
         }
@@ -733,9 +782,77 @@ bool KPDFDocument::searchText( int searchID, const QString & text, bool fromStar
     else if ( type == PrevMatch )
     {
     }
-    // 4. GOOGLELIKE //TODO
-    else if ( type == GoogleLike )
+    // 4. GOOGLE* - process all document marking pages
+    else if ( type == GoogleAll || type == GoogleAny )
     {
+        // search and highlight every word in 'text' on all pages
+        bool matchAll = type == GoogleAll;
+        QStringList words = QStringList::split( " ", text );
+        int wordsCount = words.count(),
+            hueStep = (wordsCount > 1) ? (60 / (wordsCount - 1)) : 60,
+            baseHue, baseSat, baseVal;
+        color.getHsv( &baseHue, &baseSat, &baseVal );
+        QValueVector< KPDFPage * >::iterator it = pages_vector.begin(), end = pages_vector.end();
+        for ( ; it != end; ++it )
+        {
+            // get page (from the first to the last)
+            KPDFPage * page = *it;
+            int pageNumber = page->number();
+
+            // request search page if needed
+            if ( !page->hasSearchPage() )
+                requestTextPage( pageNumber );
+
+            // loop on a page adding highlights for all found items
+            bool allMatched = wordsCount > 0,
+                 anyMatched = false;
+            for ( int w = 0; w < wordsCount; w++ )
+            {
+                QString word = words[ w ];
+                int newHue = baseHue - w * hueStep;
+                if ( newHue < 0 )
+                    newHue += 360;
+                QColor wordColor = QColor( newHue, baseSat, baseVal, QColor::Hsv );
+                NormalizedRect * lastMatch = 0;
+                // add all highlights for current word
+                bool wordMatched = false;
+                while ( 1 )
+    {
+                    if ( lastMatch )
+                        lastMatch = page->findText( word, caseSensitive, lastMatch );
+                    else
+                        lastMatch = page->findText( word, caseSensitive );
+
+                    if ( !lastMatch )
+                        break;
+
+                    // add highligh rect to the page
+                    page->setHighlight( searchID, lastMatch, wordColor );
+                    wordMatched = true;
+                }
+                allMatched = allMatched && wordMatched;
+                anyMatched = anyMatched || wordMatched;
+            }
+
+            // if not all words are present in page, remove partial highlights
+            if ( !allMatched && matchAll )
+                page->deleteHighlights( searchID );
+
+            // if page contains all words, udpate internals and queue page for notify
+            if ( (allMatched && matchAll) || (anyMatched && !matchAll) )
+            {
+                foundAMatch = true;
+                s->highlightedPages.append( pageNumber );
+                if ( !pagesToNotify.contains( pageNumber ) )
+                    pagesToNotify.append( pageNumber );
+            }
+        }
+
+        // reset cursor to previous shape
+        QApplication::restoreOverrideCursor();
+
+        // send page lists to update observers (since some filter on bookmarks)
+        foreachObserver( notifySetup( pages_vector, false ) );
     }
 
     // notify observers about highlights changes
@@ -825,7 +942,8 @@ void KPDFDocument::processLink( const KPDFLink * link )
             }
             else
             {
-                setViewport( d->nextDocumentViewport );
+                if (d->nextDocumentViewport.pageNumber == -1) return;
+                setViewport( d->nextDocumentViewport, -1, true );
                 d->nextDocumentViewport = DocumentViewport();
             }
 
@@ -905,7 +1023,13 @@ void KPDFDocument::processLink( const KPDFLink * link )
                     setNextViewport();
                     break;
                 case KPDFLinkAction::Quit:
-                    kapp->quit();
+                    emit quit();
+                    break;
+                case KPDFLinkAction::Presentation:
+                    emit linkPresentation();
+                    break;
+                case KPDFLinkAction::EndPresentation:
+                    emit linkEndPresentation();
                     break;
                 case KPDFLinkAction::Find:
                     emit linkFind();
@@ -913,6 +1037,9 @@ void KPDFDocument::processLink( const KPDFLink * link )
                 case KPDFLinkAction::GoToPage:
                     emit linkGoToPage();
                     break;
+                case KPDFLinkAction::Close:
+                    emit close();
+                    break;
             }
             } break;
 
@@ -1321,9 +1448,10 @@ DocumentViewport::DocumentViewport( int n )
     : pageNumber( n )
 {
     // default settings
-    reCenter.enabled = false;
-    reCenter.normalizedCenterX = 0.5;
-    reCenter.normalizedCenterY = 0.0;
+    rePos.enabled = false;
+    rePos.normalizedX = 0.5;
+    rePos.normalizedY = 0.0;
+    rePos.pos = Center;
     autoFit.enabled = false;
     autoFit.width = false;
     autoFit.height = false;
@@ -1333,9 +1461,10 @@ DocumentViewport::DocumentViewport( const QString & xmlDesc )
     : pageNumber( -1 )
 {
     // default settings (maybe overridden below)
-    reCenter.enabled = false;
-    reCenter.normalizedCenterX = 0.5;
-    reCenter.normalizedCenterY = 0.0;
+    rePos.enabled = false;
+    rePos.normalizedX = 0.5;
+    rePos.normalizedY = 0.0;
+    rePos.pos = Center;
     autoFit.enabled = false;
     autoFit.width = false;
     autoFit.height = false;
@@ -1359,9 +1488,18 @@ DocumentViewport::DocumentViewport( const QString & xmlDesc )
         }
         else if ( token.startsWith( "C1" ) )
         {
-            reCenter.enabled = true;
-            reCenter.normalizedCenterX = token.section( ':', 1, 1 ).toDouble();
-            reCenter.normalizedCenterY = token.section( ':', 2, 2 ).toDouble();
+            rePos.enabled = true;
+            rePos.normalizedX = token.section( ':', 1, 1 ).toDouble();
+            rePos.normalizedY = token.section( ':', 2, 2 ).toDouble();
+            rePos.pos = Center;
+        }
+        else if ( token.startsWith( "C2" ) )
+        {
+            rePos.enabled = true;
+            rePos.normalizedX = token.section( ':', 1, 1 ).toDouble();
+            rePos.normalizedY = token.section( ':', 2, 2 ).toDouble();
+            if (token.section( ':', 3, 3 ).toInt() == 1) rePos.pos = Center;
+            else rePos.pos = TopLeft;
         }
         else if ( token.startsWith( "AF1" ) )
         {
@@ -1380,9 +1518,10 @@ QString DocumentViewport::toString() const
     // start string with page number
     QString s = QString::number( pageNumber );
     // if has center coordinates, save them on string
-    if ( reCenter.enabled )
-        s += QString( ";C1:" ) + QString::number( reCenter.normalizedCenterX ) +
-             ':' + QString::number( reCenter.normalizedCenterY );
+    if ( rePos.enabled )
+        s += QString( ";C2:" ) + QString::number( rePos.normalizedX ) +
+             ':' + QString::number( rePos.normalizedY ) +
+             ':' + QString::number( rePos.pos );
     // if has autofit enabled, save its state on string
     if ( autoFit.enabled )
         s += QString( ";AF1:" ) + (autoFit.width ? "T" : "F") +
@@ -1393,13 +1532,13 @@ QString DocumentViewport::toString() const
 bool DocumentViewport::operator==( const DocumentViewport & vp ) const
 {
     bool equal = ( pageNumber == vp.pageNumber ) &&
-                 ( reCenter.enabled == vp.reCenter.enabled ) &&
+                 ( rePos.enabled == vp.rePos.enabled ) &&
                  ( autoFit.enabled == vp.autoFit.enabled );
     if ( !equal )
         return false;
-    if ( reCenter.enabled &&
-         (( reCenter.normalizedCenterX != vp.reCenter.normalizedCenterX ) ||
-         ( reCenter.normalizedCenterY != vp.reCenter.normalizedCenterY )) )
+    if ( rePos.enabled &&
+         (( rePos.normalizedX != vp.rePos.normalizedX) ||
+         ( rePos.normalizedY != vp.rePos.normalizedY ) || rePos.pos != vp.rePos.pos) )
         return false;
     if ( autoFit.enabled &&
          (( autoFit.width != vp.autoFit.width ) ||
