@@ -132,7 +132,7 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 	m_splitter->setOpaqueResize( true );
 	setWidget( m_splitter );
 	
-	m_showLeftPanel = new KToggleAction( i18n( "Show &Navigation Panel"), 0, this, SLOT( slotShowLeftPanel() ), actionCollection(), "show_leftpanel" );
+	m_showLeftPanel = new KToggleAction( i18n( "Show &Navigation Panel"), "show_side_panel", 0, this, SLOT( slotShowLeftPanel() ), actionCollection(), "show_leftpanel" );
 	m_showLeftPanel->setCheckedState( i18n( "Hide &Navigation Panel") );
 	m_showLeftPanel->setShortcut( "CTRL+L" );
 	m_showLeftPanel->setChecked( KpdfSettings::showLeftPanel() );
@@ -450,6 +450,7 @@ bool Part::openURL(const KURL &url)
         KMessageBox::error( widget(), i18n("Could not open %1").arg( url.prettyURL() ) );
     else
         m_viewportDirty.pageNumber = -1;
+    emit enablePrintAction(b);
     return b;
 }
 
@@ -639,7 +640,7 @@ void Part::slotGoToPage()
 
 void Part::slotPreviousPage()
 {
-    if ( m_document->isOpened() && !m_document->currentPage() < 1 )
+    if ( m_document->isOpened() && !(m_document->currentPage() < 1) )
         m_document->setViewportPage( m_document->currentPage() - 1 );
 }
 
