@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>                  *
- *   Copyright (C) 2004 by Albert Astals Cid <tsdgeos@terra.es>            *
+ *   Copyright (C) 2004-2006 by Albert Astals Cid <tsdgeos@terra.es>       *
  *                                                                         *
  *   With portions of code from kpdf/kpdf_pagewidget.cc by:                *
  *     Copyright (C) 2002 by Wilco Greven <greven@kde.org>                 *
@@ -25,6 +25,7 @@
 #include <qapplication.h>
 #include <qclipboard.h>
 #include <dcopclient.h>
+#include <kcursor.h>
 #include <kiconloader.h>
 #include <kurldrag.h>
 #include <kaction.h>
@@ -171,6 +172,7 @@ PageView::PageView( QWidget *parent, KPDFDocument *document )
 
 PageView::~PageView()
 {
+    d->document->removeObserver( this );
     delete d;
 }
 
@@ -721,6 +723,7 @@ void PageView::keyPressEvent( QKeyEvent * e )
                     slotAutoScoll();
                 return;
             }
+            // else fall trhough
         default:
             e->ignore();
             return;
@@ -827,7 +830,7 @@ void PageView::contentsMousePressEvent( QMouseEvent * e )
     if ( e->button() & MidButton )
     {
         d->mouseMidStartY = e->globalPos().y();
-        setCursor( sizeVerCursor );
+        setCursor( KCursor::sizeVerCursor() );
         return;
     }
 
@@ -844,7 +847,7 @@ void PageView::contentsMousePressEvent( QMouseEvent * e )
             {
                 d->mouseGrabPos = d->mouseOnRect ? QPoint() : d->mousePressPos;
                 if ( !d->mouseOnRect )
-                    setCursor( sizeAllCursor );
+                    setCursor( KCursor::sizeAllCursor() );
             }
             break;
 
@@ -1506,16 +1509,16 @@ void PageView::updateCursor( const QPoint &p )
         // if over a ObjectRect (of type Link) change cursor to hand
         d->mouseOnRect = pageItem->page()->hasObject( ObjectRect::Link, nX, nY );
         if ( d->mouseOnRect )
-            setCursor( pointingHandCursor );
+            setCursor( KCursor::handCursor() );
         else
-            setCursor( arrowCursor );
+            setCursor( KCursor::arrowCursor() );
     }
     else
     {
         // if there's no page over the cursor and we were showing the pointingHandCursor
         // go back to the normal one
         d->mouseOnRect = false;
-        setCursor( arrowCursor );
+        setCursor( KCursor::arrowCursor() );
     }
 }
 
