@@ -220,7 +220,7 @@ bool PMLayoutSettings::validateData( )
          if( ( *eit ).dockPosition( ) != PMDockWidget::DockRight )
          {
             emit showMe( );
-            KMessageBox::error( this, i18n( "The docking position of the first view layout entry has to be 'New Column'" ),
+            KMessageBox::error( this, i18n( "The docking position of the first view layout entry has to be 'New Column'." ),
                                 i18n( "Error" ) );
             return false;
          }
