@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef SVGStopElementImpl_H
@@ -26,14 +26,12 @@
 
 #include "ksvg_lookup.h"
 
-#include <kdemacros.h>
-
 namespace KSVG
 {
 
 class SVGAnimatedNumberImpl;
-class KDE_EXPORT SVGStopElementImpl : public SVGElementImpl,
-									  public SVGStylableImpl
+class SVGStopElementImpl : public SVGElementImpl,
+						   public SVGStylableImpl
 {
 public:
 	SVGStopElementImpl(DOM::ElementImpl *);
@@ -65,7 +63,7 @@ public:
 
 KSVG_REGISTER_ELEMENT(SVGStopElementImpl, "stop")
 
-};
+}
 
 #endif
 
